package MT::Plugin::RebuildAt1stView;
use strict;
use MT;
use MT::Template;

require MT::Plugin;

our $VERSION = '0.2';

use base qw( MT::Plugin );

###################################### Init Plugin #####################################

my $plugin = MT::Plugin::RebuildAt1stView->new({
    id => 'RebuildAt1stView',
    key => 'rebuild-at-1st-view',
    description => '<MT_TRANS phrase=\'_PLUGIN_DESCRIPTION\'>',
    name => 'RebuildAt1stView',
    author_name => 'Junnama Noda',
    author_link => 'http://junnama.alfasado.net/online/',
    'version' => $VERSION,
    l10n_class => 'RebuildAt1stView::L10N',
    blog_config_template => 'config.tmpl',
    schema_version => '0.1',
    settings => new MT::PluginSettings([
        ['RebuildAt1stView', { Default => 0 }],
    ]),
});

MT->add_plugin($plugin);

sub init_registry {
    my $plugin = shift;
    $plugin->registry({
        object_types => {
            'template' => {
                'rebuild_at' => 'integer',
            },
        },
        callbacks => {
            'build_file_filter'
                => \&_build_file_filter,
            'MT::App::CMS::template_source.edit_template'
                => \&_rebuld_option,
            'MT::App::CMS::template_param.edit_template'
                => \&_rebuild_flag,
        },
   });
}

sub _build_file_filter {
    my ($eh, %args) = @_;
    my $blog = $args{'Blog'};
    my $blog_id = $blog->id;
    my $get_from = 'blog:'.$blog_id;
    my $plugin_active = $plugin->get_config_value('RebuildAt1stView', $get_from);
    if ($plugin_active) {
        my $template = $args{'Template'};
        unless ($template->rebuild_at) {
            return 1;
        }
        my $redirect_url = $ENV{"REDIRECT_URL"};
        if ($redirect_url) {
            return 1;
        } else {
            my $file = $args{'file'};
            if (-e $file) {
                unlink $file;
            }
            return 0;
        }
    }
    return 1;
}

sub _rebuld_option {
    my ($cb, $app, $tmpl) = @_;
    my $blog_id = $app->blog->id;
    my $get_from = 'blog:'.$blog_id;
    my $plugin_active = $plugin->get_config_value('RebuildAt1stView', $get_from);
    if ($plugin_active) {
        my $template_options = '<mt:include name="include/actions_bar.tmpl" bar_position="bottom" hide_pager="1">';
        my $label = $plugin->translate("Plugin Options");
        my $caption = $plugin->translate("Rebuild this template at 1st view");
        my $new = <<"HTML";
    <mtapp:setting
        id="rebuild_at_1st_view"
        label="$label"
        >
        <ul>
            <li><input type="checkbox" id="rebuild_at" name="rebuild_at" value="1" <mt:if name="rebuild_at">checked="checked" </mt:if> mt:watch-change="1" /> <label for="rebuild_at">$caption</label></li>
        </ul>
        <input type="hidden" name="rebuild_at" value="0" />
    </mtapp:setting>
HTML
        my $search = quotemeta($template_options);
        $$tmpl =~ s/$search/$new$template_options/s;
    }
}

sub _rebuild_flag {
    my ($cb, $app, $param, $tmpl) = @_;
    my $q = $app->param;
    my $id = $q->param('id');
    my $template = MT::Template->load({id => $id});
    $param->{rebuild_at} = $template->rebuild_at;
}

1;